package org.infinispan.loaders;

import org.infinispan.config.CacheLoaderManagerConfig;
import org.infinispan.config.Configuration;
import org.infinispan.loaders.dummy.DummyInMemoryCacheStore;
import org.infinispan.manager.DefaultCacheManager;
import org.infinispan.manager.EmbeddedCacheManager;
import org.infinispan.test.SingleCacheManagerTest;
import org.infinispan.tree.Fqn;
import org.infinispan.tree.TreeCache;
import org.infinispan.tree.TreeCacheFactory;
import org.testng.annotations.Test;

@Test(testName = "tx.SimpleTxTest", groups = "functional")
public class TreeCacheWithLoaderDupTest extends SingleCacheManagerTest {

	TreeCache<String, String> treeCache;

	@Override
	protected EmbeddedCacheManager createCacheManager() throws Exception {
		Configuration c = new Configuration();
		c.setTransactionManagerLookupClass("org.infinispan.transaction.lookup.DummyTransactionManagerLookup");
		c.setInvocationBatchingEnabled(true);
		c.setUseLazyDeserialization(true);
		CacheLoaderManagerConfig clmc = new CacheLoaderManagerConfig();
		clmc.addCacheLoaderConfig(new DummyInMemoryCacheStore.Cfg());
		c.setCacheLoaderManagerConfig(clmc);

		EmbeddedCacheManager ecm = new DefaultCacheManager(c);
		TreeCacheFactory treeCacheFactory = new TreeCacheFactory();
		treeCache = treeCacheFactory.createTreeCache(ecm.<String, String>getCache());
		return ecm;
	}

	public void testDuplicatePersistence() throws CacheLoaderException {
		treeCache.put(Fqn.fromElements("a", "b"), "k", "v");
		assert "v".equals(treeCache.get(Fqn.fromElements("a", "b"), "k"));
		treeCache.stop();
		treeCache.start();
		treeCache.put(Fqn.fromElements("a", "b"), "k", "v");
		assert "v".equals(treeCache.get(Fqn.fromElements("a", "b"), "k"));
	}
}
